<?php
/**
 * Electronics Appliances Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Electronics Appliances
 */

use WPTRT\Customize\Section\Electronics_Appliances_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Electronics_Appliances_Button::class );

    $manager->add_section(
        new Electronics_Appliances_Button( $manager, 'electronics_appliances_pro', [
            'title'       => __( 'Electronics Pro', 'electronics-appliances' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'electronics-appliances' ),
            'button_url'  => esc_url( 'https://www.themagnifico.net/themes/home-appliances-wordpress-theme/', 'electronics-appliances')
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'electronics-appliances-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'electronics-appliances-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function electronics_appliances_customize_register($wp_customize){
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    //Header
    $wp_customize->add_section('electronics_appliances_header',array(
        'title' => esc_html__('Header Option','electronics-appliances')
    ));

    $wp_customize->add_setting('electronics_appliances_location_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('electronics_appliances_location_text',array(
        'label' => esc_html__('Location Text','electronics-appliances'),
        'section' => 'electronics_appliances_header',
        'setting' => 'electronics_appliances_location_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('electronics_appliances_location',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('electronics_appliances_location',array(
        'label' => esc_html__('Our Location','electronics-appliances'),
        'section' => 'electronics_appliances_header',
        'setting' => 'electronics_appliances_location',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('electronics_appliances_email_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('electronics_appliances_email_text',array(
        'label' => esc_html__('Email Text','electronics-appliances'),
        'section' => 'electronics_appliances_header',
        'setting' => 'electronics_appliances_email_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('electronics_appliances_email',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_email'
    ));
    $wp_customize->add_control('electronics_appliances_email',array(
        'label' => esc_html__('Email Address','electronics-appliances'),
        'section' => 'electronics_appliances_header',
        'setting' => 'electronics_appliances_email',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('electronics_appliances_phone_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('electronics_appliances_phone_text',array(
        'label' => esc_html__('Phone Text','electronics-appliances'),
        'section' => 'electronics_appliances_header',
        'setting' => 'electronics_appliances_phone_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('electronics_appliances_phone_number',array(
        'default' => '',
        'sanitize_callback' => 'electronics_appliances_sanitize_phone_number'
    ));
    $wp_customize->add_control('electronics_appliances_phone_number',array(
        'label' => esc_html__('Phone Number','electronics-appliances'),
        'section' => 'electronics_appliances_header',
        'setting' => 'electronics_appliances_phone_number',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('electronics_appliances_button_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('electronics_appliances_button_text',array(
        'label' => esc_html__('Button Text','electronics-appliances'),
        'section' => 'electronics_appliances_header',
        'setting' => 'electronics_appliances_button_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('electronics_appliances_button_link',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('electronics_appliances_button_link',array(
        'label' => esc_html__('Button Url','electronics-appliances'),
        'section' => 'electronics_appliances_header',
        'setting' => 'electronics_appliances_button_link',
        'type'  => 'text'
    ));

    // Social Link
    $wp_customize->add_section('electronics_appliances_social_link',array(
        'title' => esc_html__('Social Links','electronics-appliances'),
    ));

    $wp_customize->add_setting('electronics_appliances_facebook_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('electronics_appliances_facebook_url',array(
        'label' => esc_html__('Facebook Link','electronics-appliances'),
        'section' => 'electronics_appliances_social_link',
        'setting' => 'electronics_appliances_facebook_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('electronics_appliances_twitter_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('electronics_appliances_twitter_url',array(
        'label' => esc_html__('Twitter Link','electronics-appliances'),
        'section' => 'electronics_appliances_social_link',
        'setting' => 'electronics_appliances_twitter_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('electronics_appliances_intagram_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('electronics_appliances_intagram_url',array(
        'label' => esc_html__('Intagram Link','electronics-appliances'),
        'section' => 'electronics_appliances_social_link',
        'setting' => 'electronics_appliances_intagram_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('electronics_appliances_linkedin_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('electronics_appliances_linkedin_url',array(
        'label' => esc_html__('Linkedin Link','electronics-appliances'),
        'section' => 'electronics_appliances_social_link',
        'setting' => 'electronics_appliances_linkedin_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('electronics_appliances_youtube_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('electronics_appliances_youtube_url',array(
        'label' => esc_html__('YouTube Link','electronics-appliances'),
        'section' => 'electronics_appliances_social_link',
        'setting' => 'electronics_appliances_pintrest_url',
        'type'  => 'url'
    ));

    // Slider
    $wp_customize->add_section('electronics_appliances_top_slider',array(
        'title' => esc_html__('Slider Option','electronics-appliances')
    ));

    for ( $count = 1; $count <= 3; $count++ ) {
        $wp_customize->add_setting( 'electronics_appliances_top_slider_page' . $count, array(
            'default'           => '',
            'sanitize_callback' => 'electronics_appliances_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'electronics_appliances_top_slider_page' . $count, array(
            'label'    => __( 'Select Slide Page', 'electronics-appliances' ),
            'section'  => 'electronics_appliances_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    // Our Services
    $wp_customize->add_section('electronics_appliances_services_section',array(
        'title' => esc_html__('Our Services','electronics-appliances'),
        'description' => esc_html__('Here you have to select category which will display perticular services in the home page.','electronics-appliances')
    ));

    $categories = get_categories();
    $cat_post = array();
    $cat_post[]= 'select';
    $i = 0;
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cat_post[$category->slug] = $category->name;
    }

    $wp_customize->add_setting('electronics_appliances_services_sec_category',array(
        'default'   => 'select',
        'sanitize_callback' => 'electronics_appliances_sanitize_select',
    ));
    $wp_customize->add_control('electronics_appliances_services_sec_category',array(
        'type'    => 'select',
        'choices' => $cat_post,
        'label' => __('Select Category to display services','electronics-appliances'),
        'section' => 'electronics_appliances_services_section',
    ));

    $wp_customize->add_setting('electronics_appliances_services_per_page',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('electronics_appliances_services_per_page',array(
        'label' => esc_html__('No Of Icons','electronics-appliances'),
        'section' => 'electronics_appliances_services_section',
        'setting' => 'electronics_appliances_services_per_page',
        'type'  => 'text'
    ));

    $icon = get_theme_mod('electronics_appliances_services_per_page','');
    for ($i=1; $i <= $icon; $i++) {
        $wp_customize->add_setting('electronics_appliances_services_icon'.$i,array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field'
        ));
        $wp_customize->add_control('electronics_appliances_services_icon'.$i,array(
            'label' => esc_html__('Icon ','electronics-appliances').$i,
            'section' => 'electronics_appliances_services_section',
            'setting' => 'electronics_appliances_services_icon'.$i,
            'type'  => 'text'
        ));
    }

    // Recent Product
    $wp_customize->add_section('electronics_appliances_recent_product',array(
        'title' => esc_html__('Recent Product Option','electronics-appliances')
    ));

    $wp_customize->add_setting('electronics_appliances_recent_product_number',array(
        'default' => '',
        'sanitize_callback' => 'absint'
    ));
    $wp_customize->add_control('electronics_appliances_recent_product_number',array(
        'label' => esc_html__('No of Product','electronics-appliances'),
        'section' => 'electronics_appliances_recent_product',
        'setting' => 'electronics_appliances_recent_product_number',
        'type'  => 'number'
    ));

    $electronics_appliances_args = array(
        'type'                     => 'product',
        'child_of'                 => 0,
        'parent'                   => '',
        'orderby'                  => 'term_group',
        'order'                    => 'ASC',
        'hide_empty'               => false,
        'hierarchical'             => 1,
        'number'                   => '',
        'taxonomy'                 => 'product_cat',
        'pad_counts'               => false
    );
    $categories = get_categories( $electronics_appliances_args );
    $cats = array();
    $i = 0;
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cats[$category->slug] = $category->name;
    }
    $wp_customize->add_setting('electronics_appliances_recent_product_category',array(
        'sanitize_callback' => 'electronics_appliances_sanitize_select',
    ));
    $wp_customize->add_control('electronics_appliances_recent_product_category',array(
        'type'    => 'select',
        'choices' => $cats,
        'label' => __('Select Product Category','electronics-appliances'),
        'section' => 'electronics_appliances_recent_product',
    ));
    
    // Footer
    $wp_customize->add_section('electronics_appliances_site_footer_section', array(
        'title' => esc_html__('Footer', 'electronics-appliances'),
    ));

    $wp_customize->add_setting('electronics_appliances_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('electronics_appliances_footer_text_setting', array(
        'label' => __('Replace the footer text', 'electronics-appliances'),
        'section' => 'electronics_appliances_site_footer_section',
        'priority' => 1,
        'type' => 'text',
    ));
}
add_action('customize_register', 'electronics_appliances_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function electronics_appliances_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function electronics_appliances_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function electronics_appliances_customize_preview_js(){
    wp_enqueue_script('electronics-appliances-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'electronics_appliances_customize_preview_js');